<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml_idp\Form\MiniorangeIDPSetup.
 */

namespace Drupal\miniorange_saml_idp\Form;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml_idp\MiniorangeSAMLIdpConstants;
use Drupal\miniorange_saml_idp\Utilities;
use Drupal\miniorange_saml_idp\MetadataReader;

class MiniorangeIDPSetup extends FormBase {

  public function getFormId() {
    return 'miniorange_saml_idp_setup';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
  {
      global $base_url;

      Utilities::visual_tour_start($form, $form_state);

      $form['miniorange_saml_SP_tab'] = array(
          '#attached' => array(
              'library' => array(
                  'miniorange_saml_idp/miniorange_saml_idp.test',
              )
          ),
      );

      $form['metadata_1'] = array(
          '#markup' =>'<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container"><div id="tabhead"><br><h5> Enter the information gathered from your Service Provider &nbsp; OR &nbsp;&nbsp;
                    <a id="showMetaButton" class="mo_idp_btn mo_idp_btn-primary mo_idp_btn-sm" onclick="testConfig()">Upload SP Metadata</a>&nbsp;&nbsp;&nbsp;&nbsp;
                    <a id="Restart_moTour" class="mo_idp_btn mo_idp_btn-danger mo_idp_btn-sm miniorange_float_right" onclick="Restart_moTour()">Take a Tour</a>
                    <br></h5><hr></div><div border="1" id="upload_metadata_form" class="mo_saml_meta_upload"><h2>Upload SP Metadata &nbsp;&nbsp;
              		   <span class="mo_saml_cancel_upload"><a id="hideMetaButton" class="mo_idp_btn mo_idp_btn-sm mo_idp_btn-danger miniorange_float_right" onclick = "testConfig()">Cancel</a></span></h2><hr><hr><br>',
      );

      $form['metadata_file'] = array(
          '#type' => 'file',
          '#title' => 'Upload Metadata',
          '#attributes' => array('style' => 'width:65%'),
          '#prefix' => '<br><br>',
      );

      $form['metadata_upload'] = array(
          '#type' => 'submit',
          '#value' => t('Upload'),
          '#submit' => array('::miniorange_saml_upload_file'),
          '#attributes' => array('style' => 'border-radius:4px;background: #337ab7;color: #ffffff;text-shadow: 0 -1px 1px #337ab7, 1px 0 1px #337ab7, 0 1px 1px #337ab7, -1px 0 1px #337ab7;
                box-shadow: 0 1px 0 #337ab7;border-color: #337ab7 #337ab7 #337ab7;float: right;margin-top: -39px;width: 150px;'),
          '#suffix' => '<br><div class="mo_saml_text_center"><b>OR</b></div>',
      );

      $form['metadata_URL'] = array(
          '#type' => 'textfield',
          '#title' => t('Enter metadata URL:'),
          '#attributes' => array('style' => 'width:65%','placeholder' => 'Enter metadata URL of your SP.'),
      );

      $form['metadata_fetch'] = array(
          '#type' => 'submit',
          '#value' => t('Fetch Metadata'),
          '#submit' => array('::miniorange_saml_fetch_metadata'),
          '#attributes' => array('style' => 'border-radius:4px;background: #337ab7;color: #ffffff;text-shadow: 0 -1px 1px #337ab7, 1px 0 1px #337ab7, 0 1px 1px #337ab7, -1px 0 1px #337ab7;
            box-shadow: 0 1px 0 #337ab7;border-color: #337ab7 #337ab7 #337ab7;float: right;margin-top: -39px;'),
          '#suffix' => '<br><br><br><br></div>',
      );

      $form['markup_idp_note'] = array(
        '#markup' => '<div id="idpdata"><br><div class = "mo_saml_highlight_background_note"><b>Note: </b>Please note down the following information from your 
                           Service Provider and keep it handy to configure your Identity Provider.</div><br>',
      );

      $form['markup_idp_list'] = array(
            '#markup' => '<b><ol><li>SP Entity ID / Issuer</li>
              <li>ACS URL</li>
              <li>X.509 Certificate for Signing if you are using HTTP-POST Binding. [This is a
              <a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'">Premium</a> feature]</li>
              <li>X.509 Certificate for Encryption. [This is a
              <a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'">Premium</a> feature]</li>
              <li>NameID Format</li></ol></b><br>',
      );

      $form['miniorange_saml_idp_name'] = array(
          '#type' => 'textfield',
          '#title' => t('Service Provider Name<span style="color: red">*</span>'),
          '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_name'),
          '#attributes' => array(
              'style' => 'width:700px',
              'placeholder' => 'Enter Service Provider Name'
          ),
          '#prefix' => '<div>'
      );

      $form['miniorange_saml_idp_entity_id'] = array(
        '#type' => 'textfield',
        '#title' => t('SP Entity ID or Issuer<span style="color: red">*</span>'),
        '#description' => t('<b>Note :</b> You can find the EntityID in Your SP-Metadata XML file enclosed in <code>EntityDescriptor</code> tag having attribute<br> as <code>entityID</code>.'),
        '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_entity_id'),
        '#attributes' => array('style' => 'width:700px','placeholder' => 'Enter SP Entity ID or Issuer'),
      );

      $form['miniorange_saml_idp_nameid_format'] = array(
        '#type' => 'select',
        '#title' => t('NameID Format:'),
        '#options' => array(
            '1.1:nameid-format:emailAddress' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress'),
            '1.1:nameid-format:unspecified' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified'),
            '2.0:nameid-format:transient' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:transient'),
            '2.0:nameid-format:persistent' => t('urn:oasis:names:tc:SAML:1.1:nameid-format:persistent'),
         ),
        '#default_value' =>\Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_nameid_format'),
        '#attributes' => array('style' => 'width:700px;background-image: inherit;background-color: white;-webkit-appearance: menulist;'),
        '#description' => t('(<b>NOTE:</b> urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress is selected by default)'),
      );

      $form['miniorange_saml_idp_acs_url'] = array(
        '#type' => 'textfield',
        '#title' => t('ACS URL<span style="color: red">*</span>'),
        '#description' => t('<b>Note :</b> You can find the SAML Login URL in Your SP-Metadata XML file enclosed in <code>AssertionConsumerService </code> tag <br/>having attribute as <code>Location</code>.'),
        '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_acs_url'),
        '#attributes' => array('style' => 'width:700px','placeholder' => 'Enter ACS URL'),
      );

      $form['miniorange_saml_idp_relay_state'] = array(
        '#type' => 'textfield',
        '#title' => t('Relay State'),
        '#description' => t('<b>Note:</b> To identify the specific resource at the resource provider in the IDP initiated SSO. It specifes the landing page</br> at the service provider once SSO completes.'),
        '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_relay_state'),
        '#attributes' => array('style' => 'width:700px','placeholder' => 'Enter Relay State (optional)'),
      );

      $form['miniorange_saml_idp_single_logout_url'] = array(
          '#type' => 'textfield',
          '#title' => t('Single Logout URL (optional):<a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'"> [Premium]</a>'),
          '#attributes' => array('style' => 'width:700px','placeholder' => 'Enter Sinle Logout URL'),
          '#disabled' => TRUE,
          '#suffix' => '<br>',
      );

      $form['miniorange_saml_idp_x509_certificate_request'] = array(
          '#type' => 'textarea',
          '#title' => t('x.509 Certificate Value  <b>[Note: For Signed Request.] </b><a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'"> [Premium]</a>'),
          '#cols' => '10',
          '#rows' => '5',
          '#attributes' => array('style' => 'width:700px','placeholder' => 'Copy and Paste the content from the downloaded certificate or copy the content enclosed in X509Certificate tag (has parent tag KeyDescriptor use=signing) in SP-Metadata XML file)'),
          '#disabled' => TRUE,
          '#description' => '<b>NOTE:</b> Format of the certificate:<br><b>-----BEGIN CERTIFICATE-----<br>XXXXXXXXXXXXXXXXXXXXXXXXXXX<br>-----END CERTIFICATE-----</b>',
      );

      $form['miniorange_saml_idp_x509_certificate_assertion'] = array(
          '#type' => 'textarea',
          '#title' => t('x.509 Certificate Value <b>[Note: For Encrypted Assertion.]</b> <a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'"> [Premium]</a>'),
          '#cols' => '10',
          '#rows' => '5',
          '#attributes' => array('style' => 'width:700px','placeholder' => 'Copy and Paste the content from the downloaded certificate or copy the content enclosed in X509Certificate tag (has parent tag KeyDescriptor use=encryption)'),
          '#disabled' => TRUE,
          '#description' => '<b>NOTE:</b> Format of the certificate:<br><b>-----BEGIN CERTIFICATE-----<br>XXXXXXXXXXXXXXXXXXXXXXXXXXX<br>-----END CERTIFICATE-----</b>',
      );

      $form['miniorange_saml_idp_assertion_signed'] = array(
          '#type' => 'checkbox',
          '#title' => t('<b>Assertion Signed</b>'),
          '#default_value' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_assertion_signed'),
          '#description' => '<b>Note:</b> Check this if you want to sign SAML Assertion.',
          '#prefix' => '<div id="assertion_signed"><br>',
          '#suffix' => '</div>',
      );

      $form['miniorange_saml_idp_response_signed'] = array(
         '#markup' => '<br>',
         '#type' => 'checkbox',
         '#title' => t('<b>Response Signed:</b>'),
         '#disabled' => TRUE,
          '#description' => '<b>Note:</b> This feature is available in the<a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'"> Premium </a>version of the module.',
         '#prefix' => '<div class="mo_saml_highlight_background_note">',
      );

      $form['miniorange_saml_idp_encrypt_signed'] = array(
         '#type' => 'checkbox',
         '#title' => t('<b>Encrypted Assertion:</b>'),
         '#disabled' => TRUE,
          '#description' => '<b>Note:</b> This feature is available in the<a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'"> Premium </a>version of the module.',
         '#suffix' => '</div><br><br><br>',
      );



      $form['miniorange_saml_idp_config_submit'] = array(
          '#type' => 'submit',
          '#value' => t('Save Configuration'),
      );

      $testConfigUrl = "\'" . $this->getTestUrl() . "\'";
      $form['miniorange_saml_idp_test_config_button'] = array (
          '#attached' => array(
              'library' => 'miniorange_saml_idp/miniorange_saml_idp.test',
          ),
          '#markup' => '<a id="testConfigButton" class="mo_idp_btn mo_idp_btn-success mo_idp_btn-sm" onclick="testIdpConfig($testConfigUrl);"><b>Test Configuration</b></a>',
      );

      $entity_id = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_entity_id');
      $ACS_URL = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_idp_acs_url');
      $disableButton = FALSE;
      if($entity_id == NULL || $ACS_URL == NULL)
          $disableButton = TRUE;

      $form['miniorange_saml_idp_config_delete'] = array(
          '#type' => 'submit',
          '#value' => t('Delete Configuration'),
          '#submit' => array('::miniorange_saml_idp_delete_idp_config'),
          '#attributes' => array('style' => 'border-radius:4px; background: #d9534f; color: #ffffff; text-shadow: 0 -1px 1px #d43f3a, 1px 0 1px #d43f3a, 0 1px 1px #d43f3a, -1px 0 1px #d43f3a;box-shadow: 0 1px 0 #d43f3a;border-color: #d43f3a;'),
          '#disabled' => $disableButton,
          '#suffix' => '<br><br></div></div></div>',
      );

      Utilities::spConfigGuide($form, $form_state);

      Utilities::AddSupportButton($form, $form_state);

  return $form;
 }

 function getTestUrl() {
    global $base_url;
    $testUrl = $base_url . '/?q=testConfig';
    return $testUrl;
 }

 
 function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
 {
         $sp_name = $form['miniorange_saml_idp_name']['#value'];
         $issuer = $form['miniorange_saml_idp_entity_id']['#value'];
         $acs_url = $form['miniorange_saml_idp_acs_url']['#value'];
         $relay_state = $form['miniorange_saml_idp_relay_state']['#value'];
         $nameid_format = $form['miniorange_saml_idp_nameid_format']['#value'];
         $is_assertion_signed = $form['miniorange_saml_idp_assertion_signed']['#value'] == 1 ? TRUE : FALSE;

         if( empty( $sp_name ) || empty( $issuer ) || empty( $acs_url ) ){
             \Drupal::messenger()->addMessage(t('The <b>Service Provider Name, SP Entity ID or Issuer, ACS URL</b> field is required.'), 'error');
             return;
         }

         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_name', $sp_name)->save();
         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_entity_id', str_replace(' ', '', $issuer))->save();
         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_acs_url', str_replace(' ', '', $acs_url))->save();
         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_relay_state', $relay_state)->save();
         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_nameid_format', $nameid_format)->save();
         \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->set('miniorange_saml_idp_assertion_signed', $is_assertion_signed)->save();

         \Drupal::messenger()->addMessage(t('Your Service Provider Configuration are successfully saved. You can click on Test Configuration button below to test these configurations.'));
 }

    function miniorange_saml_idp_delete_idp_config(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->clear('miniorange_saml_idp_name')->save();
        \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->clear('miniorange_saml_idp_entity_id')->save();
        \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->clear('miniorange_saml_idp_acs_url')->save();
        \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->clear('miniorange_saml_idp_assertion_signed')->save();
        \Drupal::configFactory()->getEditable('miniorange_saml_idp.settings')->clear('miniorange_saml_idp_relay_state')->save();

        \Drupal::messenger()->addMessage(t('Service Provider Configuration successfully deleted.'));
    }

    function miniorange_saml_upload_file(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
        $file_name = $_FILES['files']['tmp_name']['metadata_file'];
        if(!empty($file_name)){
          $file = file_get_contents($file_name);
          Utilities::upload_metadata( $file, $type = 'file' );
        }
        else
          \Drupal::messenger()->addMessage(t('Select a metadata file to configure.'),'error');
    }

    function miniorange_saml_fetch_metadata(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
       $url = filter_var($form['metadata_URL']['#value'],FILTER_SANITIZE_URL);

       if(!empty($url)){
         $arrContextOptions=array(
              "ssl"=>array(
                  "verify_peer"=>false,
                  "verify_peer_name"=>false,
              ),
         );
         $file = file_get_contents($url, false, stream_context_create($arrContextOptions));
         Utilities::upload_metadata( $file, $type = 'URL' );
       }
       else
          \Drupal::messenger()->addMessage(t('Enter metadata url to configure.'),'error');
    }
}