<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml_idp\Form\MiniorangeSPInformation.
 */

namespace Drupal\miniorange_saml_idp\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml_idp\MiniorangeSAMLIdpConstants;
use Drupal\miniorange_saml_idp\Utilities;

class MiniorangeSPInformation extends FormBase
{
  public function getFormId() {
    return 'miniorange_sp_setup';
  }
  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
  {
      global $base_url;
      Utilities::visual_tour_start($form, $form_state);
      $login_url = $base_url . '/initiatelogon';
      $issuer = $base_url . '/?q=admin/config/people/miniorange_saml_idp/';
      $module_path = drupal_get_path('module', 'miniorange_saml_idp');
      $issuer_id = isset($issuer_id) && !empty($issuer_id)? $issuer_id:$issuer;

      $form['markup_style_1'] = array(
            '#attached' => array(
                'library' => array(
                    'miniorange_saml_idp/miniorange_saml_idp_copy.icon',
                )
            ),
            '#markup' => '<div class="mo_saml_table_layout_1">',
      );

      $form['miniorange_saml_idp_div_st'] = array(
          '#markup' => '<div class="mo_saml_table_layout mo_saml_container"><h2>Identity Provider Metadata&nbsp;&nbsp; 
                <a id="Restart_moTour" class="mo_idp_btn mo_idp_btn-danger mo_idp_btn-sm miniorange_float_right" onclick="Restart_moTour()">Take a Tour</a></h2><hr><br><br>',
      );

      $form['mo_saml_metadata_option'] = array(
          '#markup' => '<div><b>Provide this module information to your Service Provider team. You can choose any one of the below options:</b></div>
                             <br><b>a) Provide this metadata URL to your Service Provider:</b><br>',
      );

      $form['markup_idp_sp_2'] = array(
          '#markup' => '<div>
                            <div class="mo_idp_mo_saml_highlight_background_url_note" id="idp_metadata_url">
                                <code><b>
                                    <span>
                                        <a target="_blank" href="' . $base_url . '/moidp_metadata">' . $base_url . '/moidp_metadata</a>
                                    </span></b>
                                </code>
                            </div>
                            <img class ="mo_idp_fa mo_idp_fa-fw mo_idp_fa-lg mo_idp_fa-copy mo_idp_mo_copy mo_idp_mo-margin" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">
                        </div>',
      );

      $form['mo_saml_download_btn_title'] = array(
          '#markup' => '<br><br><div id="download_metadata_file"><b>b) Download the Module XML metadata and upload it on your Service Provider : </b>
                                <span><a href="' . $base_url . '/moidp_metadata_download" class="mo_idp_btn mo_idp_btn-primary mo_idp_btn-sm">Download XML Metadata</a></span>
                        </div><br><br><div><b>c) Provide the following information to your Service Provider. Copy it and keep it handy.</b></div><br>',
      );

      $form['mo_saml_attrs_list_idp'] = array(
          '#markup' => '<div class="table-responsive" style="font-family: sans-serif;font-size: 12px;" id="mo_idp_vt_conf_table">   
                <table class="mo_guide_table mo_guide_table-striped mo_copy_icon_not_center" style="border: 1px solid #ddd;max-width: 100%;border-collapse: collapse;">
                    <thead>
                        <tr>
                            <th class="mo_guide_text-center mo_td_values">ATTRIBUTE</th>
                            <th class="mo_guide_text-center mo_td_values">VALUE</th>   
                            <tbody style="font-size: 12px;color:gray;">     
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">IDP-Entity ID / Issuer</td>
                                    <td>						               
						               <span id="issuer_id">' . $issuer_id . '</span>						                 
                                       <img class ="mo_idp_fa mo_idp_fa-fw mo_idp_fa-pull-right mo_idp_fa-lg fa-copy mo_idp_mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>                                
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SAML Login URL</td>
                                    <td>						               
						               <span id="login_url">' . $login_url . '</span>						                 
                                       <img class ="mo_idp_fa mo_idp_fa-fw mo_idp_fa-pull-right mo_idp_fa-lg mo_idp_fa-copy mo_idp_mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SAML Logout URL</td>
                                    <td>						               
						               Available in </b><a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'">Premium</a> version.		
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Certificate (Optional)	</td>
                                    <td>						               
						                <a href="' . $base_url . '/' . $module_path . '/resources/idp-signing.crt">Click Here</a> to download X509 certificate. 
						            </td>                                    
                                </tr> 
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Response Signed</td>
                                    <td>						               
						               Available in </b><a href="' . $base_url . MiniorangeSAMLIdpConstants::LICENSE_PAGE_URL .'">Premium</a> version.		
						            </td>
                                </tr>                                                                                        
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Assertion Signed</td> 
                                    <td style="padding: 15px;">You can choose to sign your assertion in <a href="' . $base_url . '/admin/config/people/miniorange_saml_idp/idp_setup">Service Provider Setup</a></td>
                                </tr>                              
                            </tbody>                                                 
                        </tr>
                    </thead>
                    </table>
          </div></div>'
      );

      Utilities::spConfigGuide($form, $form_state);

      Utilities::AddSupportButton($form, $form_state);

      return $form;
  }

  public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

  }
}